@@ -135,7 +135,7 @@ DROP SCHEMA test;
 FLUSH PRIVILEGES;
 SQL
 
-        P->sys->system( 'mysql_install_db', q[--defaults-file=] . $self->alien_cfg_path );
+        P->pm->run_check( 'mysql_install_db', q[--defaults-file=] . $self->alien_cfg_path );
 
         open my $MYSQLD, '|-', $self->alien_bin_path . ' --defaults-file=' . $self->alien_cfg_path . '  --bootstrap --default-storage-engine=myisam --loose-skip-innodb --loose-skip-ndbcluster' or die;
 
